package com.ruoyi.mall.service;

import java.util.List;

import com.github.pagehelper.PageInfo;
import com.ruoyi.mall.domain.MallTestSchool;
import com.ruoyi.mall.domain.Vo.TextSchoolVO;
import org.apache.ibatis.annotations.Param;

/**
 * 校考院校Service接口
 *
 * @author ruoyi
 * @date 2023-11-01
 */
public interface IMallTestSchoolService
{
    /**
     * 查询校考院校
     *
     * @param testSchoolId 校考院校主键
     * @return 校考院校
     */
    public MallTestSchool selectMallTestSchoolByTestSchoolId(Long testSchoolId);

    /**
     * 查询校考院校列表
     *
     * @param mallTestSchool 校考院校
     * @return 校考院校集合
     */
    public List<MallTestSchool> selectMallTestSchoolList(MallTestSchool mallTestSchool);

    /**
     * 新增校考院校
     *
     * @param mallTestSchool 校考院校
     * @return 结果
     */
    public int insertMallTestSchool(MallTestSchool mallTestSchool);

    /**
     * 修改校考院校
     *
     * @param mallTestSchool 校考院校
     * @return 结果
     */
    public int updateMallTestSchool(MallTestSchool mallTestSchool);

    /**
     * 批量删除校考院校
     *
     * @param testSchoolIds 需要删除的校考院校主键集合
     * @return 结果
     */
    public int deleteMallTestSchoolByTestSchoolIds(Long[] testSchoolIds);

    /**
     * 删除校考院校信息
     *
     * @param testSchoolId 校考院校主键
     * @return 结果
     */
    public int deleteMallTestSchoolByTestSchoolId(Long testSchoolId);

    /**
     * 校考院校
     * @param searchValue 搜索词
     * @param acceptYear 年份
     * @param majorId 专业id
     * @return 结果
     */
    public PageInfo<TextSchoolVO> selectTestSchoolList(String searchValue,
                                                         String acceptYear,
                                                       Integer majorId,
                                                       Integer pageNum,
                                                       Integer pageSize);
}
